==> logs-1.101.0-sources.jar: software/amazon/awscdk/services/logs/JsonPattern.java <==
package software.amazon.awscdk.services.logs;

/**
 * Base class for patterns that only match JSON log events.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:07:41.996Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.logs.$Module.class, fqn = "@aws-cdk/aws-logs.JsonPattern")
public abstract class JsonPattern extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.logs.IFilterPattern {

    protected JsonPattern(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected JsonPattern(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param jsonPatternString This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected JsonPattern(final @org.jetbrains.annotations.NotNull java.lang.String jsonPatternString) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(jsonPatternString, "jsonPatternString is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getJsonPatternString() {
        return software.amazon.jsii.Kernel.get(this, "jsonPatternString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getLogPatternString() {
        return software.amazon.jsii.Kernel.get(this, "logPatternString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends software.amazon.awscdk.services.logs.JsonPattern implements software.amazon.awscdk.services.logs.IFilterPattern.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }
    }
}

==> logs-1.153.1-sources.jar: software/amazon/awscdk/services/logs/JsonPattern.java <==
package software.amazon.awscdk.services.logs;

/**
 * Base class for patterns that only match JSON log events.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // Search for all events where the component field is equal to
 * // "HttpServer" and either error is true or the latency is higher
 * // than 1000.
 * JsonPattern pattern = FilterPattern.all(FilterPattern.stringValue("$.component", "=", "HttpServer"), FilterPattern.any(FilterPattern.booleanValue("$.error", true), FilterPattern.numberValue("$.latency", "&gt;", 1000)));
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.57.0 (build f614666)", date = "2022-04-23T01:54:29.544Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.logs.$Module.class, fqn = "@aws-cdk/aws-logs.JsonPattern")
public abstract class JsonPattern extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.logs.IFilterPattern {

    protected JsonPattern(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected JsonPattern(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param jsonPatternString This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected JsonPattern(final @org.jetbrains.annotations.NotNull java.lang.String jsonPatternString) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(jsonPatternString, "jsonPatternString is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getJsonPatternString() {
        return software.amazon.jsii.Kernel.get(this, "jsonPatternString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getLogPatternString() {
        return software.amazon.jsii.Kernel.get(this, "logPatternString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends software.amazon.awscdk.services.logs.JsonPattern implements software.amazon.awscdk.services.logs.IFilterPattern.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }
    }
}
